import greenfoot.*;  // （World、Actor、GreenfootImage、GreenfootSound、Greenfoot及MouseInfo）
import java.awt.Color;

/**
 * 長方形。
 * 
 * @author 依瑪貓
 * @version 2012-08-29
 */
public abstract class Rect extends Actor
{
    /** 長方形的寬。 */
    private int width = -1;
    
    /** 長方形的長。 */
    private int height = -1;
    
    /** 每次的移動距離。 */
    private final static int dX = 5;
    
    /** 長方形的顏色。 */
    private Color color;
    
    /**
     * 建立新的長方形。
     * 
     * @param width 長方形的寬
     * @param height 長方形的高
     * @param color 顏色
     */
    public Rect(int width, int height, Color color) {
        this.width = width;
        this.height = height;
        this.color = color;
        drawImage();
    }
    
    /**
     * 繪製長方形。
     * 
     */
    public void drawImage() 
    {
        GreenfootImage image = new GreenfootImage(width, height);
        image.setColor(color);
        image.fill();
        setImage(image);
    }
    
    /**
     * 取得長方形的寬。
     * 
     * @return 長方形的寬
     */
    public int getWidth() {
        return width;
    }
    
    /**
     * 取得長方形的高。
     * 
     * @return 長方形的高
     */
    public int getHeight() {
        return height;
    }
    
    /**
     * 取得 X 軸半徑。
     * 
     * @return X 軸半徑
     */
    public int getRadiusX() {
        return width / 2;
    }
    
    /**
     * 取得 Y 軸半徑。
     * 
     * @return Y 軸半徑
     */
    public int getRadiusY() {
        return height / 2;
    }
}